@@ -22,8 +22,10 @@
 
 #include <stdlib.h>
 #include <stdio.h>
-
+#include <algorithm>
+#include <numeric>
 #include <vector>
+#include <utility>
 
 using std::vector;
 
@@ -32,6 +34,8 @@ struct linear_fit_result
   double slope;
   // average residual sum squares
   double average_rss;
+  // normalized standard deviation
+  double normalized_std;
   // coefficient of determination R^2
   double r_square;
 };
@@ -45,6 +49,14 @@ void getfivepointstencilderivative(const vector<double>& v, vector<double>& dv);
 linear_fit_result slope_straight_line_fit(const vector<double>& x,
                                           const vector<double>& y);
 
+template <class T>
+double vec_median(vector<T> v);
+template <class T>
+double vec_mean(const vector<T> &v);
+
+std::pair<size_t, size_t> get_time_index(std::vector<double> &t, double startTime,
+                                     double endTime, double precisionThreshold);
+      
 template <class ForwardIterator>
 ForwardIterator first_min_element(ForwardIterator first, ForwardIterator last) {
   ForwardIterator lowest = first;
